@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12067 2020-04-11 14:38:53Z Trista $
+# $Id: __init__.py 12213 2020-05-13 14:02:01Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-04-11 23:38:53 +0900 (週六, 11 四月 2020) $
-# $Revision: 12067 $
+# $Author: Lavender $ (last)
+# $Date: 2020-05-13 22:02:01 +0800 (週三, 13 五月 2020) $
+# $Revision: 12213 $
 
 import os
 import sys
@@ -652,7 +652,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     
     
 
-def attachShopURLs(settings, urlpatterns):
+def attachURLs(settings, urlpatterns):
     """
     Attach shop related urlpatterns.
     It must be called in urls.py by passing urlpatterns.
